# Smallparts

A humble collection of convenience modules for use with Python 3

This package mainly focuses on text conversion and generation.

When coding in Python, I found myself copying the same modules into my
projects over and over again, doing a few changes here and there and
ended up with slightly different modules with the same functionality.
So one day I decided to put an end to that and transfer my frequently used
helper modules to a single source of truth.  
Here they are, in good hope that they might be useful to others as well.

* Package documentation: <https://blackstream-x.github.io/smallparts/>
* Installable resources: <https://pypi.org/project/smallparts/>

----

> Please note: When creating this project on GitHub, I forked it off
> the sample project (<https://github.com/pypa/sampleproject>)
> from the Python Packaging User Guide’s recommendable
> [Tutorial on Packaging and Distributing Projects](https://packaging.python.org/guides/distributing-packages-using-setuptools/).  
> Apart from the basic structure of the package,
> this project shares nothing anymore with its parent.
> Nevertheless, GitHub shows a huge number of forks, but these are forks
> of the sample project, not of this one.
